.. UN Statistics Division RDF API documentation master file, created by
   sphinx-quickstart on Wed Aug 18 12:05:31 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

UN Statistics Division RDF API
==============================

This python module contains some classifications and standards
that come from the `UN Statistics Division`_ developed by the
`Open Knowledge Foundation`_ largely for use with the
`Where Does My Money Go?`_ project.

**Disclaimer:** this software is neither produced by nor endorsed
by any UN agency.

.. _UN Statistics Division: http://unstats.un.org/
.. _Open Knowledge Foundation: http://okfn.org/
.. _Where Does My Money Go?: http://www.wheredoesmymoneygo.org/

Data Sources
------------

This EGG contains some `datapkg` data sources that are used by the
modules, you can see them by doing, for example::

    % datapkg list egg://unstats_rdf
    cofog99_fr -- COFOG 1999 via the EU in XML format (French labels)
    cofog99_de -- COFOG 1999 via the EU in XML format (German labels)
    cofog99_en -- COFOG 1999 via the EU in XML format (English labels)

.. _datapkg: http://okfn.org/datapkg

Contents:

.. toctree::
   :maxdepth: 2

   api_docs.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

